Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1221)

Unified Diff: testing/buildbot/manage.py

Issue 2731973003: Add Mac10.12 continuous builder and try bot config (src repo). (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « testing/buildbot/chromium.webkit.json ('k') | tools/mb/mb_config.pyl » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: testing/buildbot/manage.py
diff --git a/testing/buildbot/manage.py b/testing/buildbot/manage.py
index c4e8745923bde31710680ae6bd9fe774dbaff7a5..1960baec4540006786b0cf40c6e86d4ce99dbb38 100755
--- a/testing/buildbot/manage.py
+++ b/testing/buildbot/manage.py
@@ -60,10 +60,11 @@ SKIP = {
# http://crbug.com/441429
'Linux Trusty (32)', 'Linux Trusty (dbg)(32)',
# swarming may not work on Mac10.10 and 10.11, need to
# re-investigate and confirm
'WebKit Mac10.10',
'WebKit Mac10.11',
+ 'WebKit Mac10.12',
'WebKit Mac10.11 (dbg)',
'WebKit Mac10.11 (retina)',
'Chromium Mac10.10 Tests',
@@ -60,10 +60,11 @@ SKIP = {
# http://crbug.com/441429
'Linux Trusty (32)', 'Linux Trusty (dbg)(32)',
- # swarming may not work on Mac10.10 and 10.11, need to
- # re-investigate and confirm
+ # Swarming may not work on Mac10.10,11,12; need to
+ # re-investigate and confirm.
'WebKit Mac10.10',
'WebKit Mac10.11',
« no previous file with comments | « testing/buildbot/chromium.webkit.json ('k') | tools/mb/mb_config.pyl » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698